==> qore-1.16.1.tar.bz2: qore-1.16.1/include/qore/intern/QC_Counter.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  QC_Counter.h

  Qore Programming Language

  Copyright (C) 2003 - 2023 Qore Technologies, s.r.o.

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QORE_CLASS_COUNTER_H

#define _QORE_CLASS_COUNTER_H

#include <qore/QoreCounter.h>
#include <qore/AbstractPrivateData.h>

DLLEXPORT extern qore_classid_t CID_COUNTER;
DLLLOCAL extern QoreClass* QC_COUNTER;

DLLLOCAL QoreClass *initCounterClass(QoreNamespace& ns);

class Counter : public AbstractPrivateData, public QoreCounter {
   protected:
      DLLLOCAL virtual ~Counter() {}

   public:
      DLLLOCAL Counter(int nc = 0) : QoreCounter(nc) {}
};

#endif // _QORE_CLASS_COUNTER_H

==> qore-2.2.0.tar.bz2: qore-2.2.0/include/qore/intern/QC_Counter.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  QC_Counter.h

  Qore Programming Language

  Copyright (C) 2003 - 2024 Qore Technologies, s.r.o.

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QORE_CLASS_COUNTER_H

#define _QORE_CLASS_COUNTER_H

#include <qore/QoreCounter.h>
#include <qore/AbstractPrivateData.h>

DLLEXPORT extern qore_classid_t CID_COUNTER;
DLLEXPORT extern QoreClass* QC_COUNTER;

DLLLOCAL QoreClass* initCounterClass(QoreNamespace& ns);

#endif // _QORE_CLASS_COUNTER_H
